<!DOCTYPE html>
<html lang="en">
<head>
    {% block head %}
        <meta charset="UTF-8" />
        <title>{% block title %}ChecklistFabrik{% endblock %}</title>
        <link rel="stylesheet" href="/assets/css/docs.min.css" />
        <link rel="stylesheet" href="/assets/css/fontawesome.min.css" />
        <link rel="stylesheet" href="/assets/css/fontawesome-solid.min.css" />
        <link rel="stylesheet" href="/assets/css/spectre.min.css" />
        <link rel="stylesheet" href="/assets/css/spectre-icons.min.css" />
        <link rel="stylesheet" href="/assets/css/style.css" />
        <meta name="viewport" content="initial-scale=1" />
        <meta http-equiv="content-security-policy" content="default-src 'self' 'unsafe-inline' data:" />
    {% endblock %}
</head>

<body>
{% block body %}
{% endblock %}


<div class="docs-footer container grid-lg" id="copyright">
    <p>
        <a href="https://github.com/Linuxfabrik/checklistfabrik">ChecklistFabrik</a>
        was <i class="fa fa-code text-primary" aria-label="coded" role="img"></i>
        with <span class="text-error">&hearts;</span>
        by <a href="https://linuxfabrik.ch" target="_blank">Linuxfabrik GmbH</a> in Zurich/Switzerland.
        Licensed under the <a href="https://unlicense.org" target="_blank">UNLICENSE</a>.
    </p>
</div>
</body>
</html>
