{% extends 'base.html.j2' %}

{% block body %}
    <div class="container grid-lg py-2">
        <h2>Checklist completed</h2>

        <p>You can now exit ChecklistFabrik and close this page.</p>

        <div style="margin-bottom: 1.2rem;">
            <a class="btn" href="/page/{{ last_page_id }}">Back</a>
            <a class="btn btn-primary" href="/exit">Save and Exit</a>
        </div>
    </div>
{% endblock %}
