"""
ChecklistFabrik import module stub

This module is a stub as it represents core functionality.

EXAMPLE::

    - linuxfabrik.clf.import: 'file-to-import.yml'
"""

HTML = '''\
<div class="toast toast-error">
    <em>linuxfabrik.clf.import</em> represents the core import functionality and should never actually be rendered on a checklist.<br />
    If you encounter this message on your checklist, it indicates that an unreachable state has been reached. Please report this issue.
</div>
'''


def main(**kwargs):
    return {
        'html': HTML,
    }
