<div class="d-flex" style="justify-content: space-between; margin-bottom: 1.2rem;">
    <div class="d-flex" style="gap: 0.4rem;">
        {% if page_id > 0 %}
            <input class="btn" form="checklist_form" formnovalidate="formnovalidate" name="submit_action" type="submit" value="Previous" />
        {% endif %}

        <input class="btn btn-primary" form="checklist_form" name="submit_action" type="submit" value="Next" />
    </div>
    <input class="btn btn-error" form="checklist_form" formnovalidate="formnovalidate" name="submit_action" type="submit" value="Save and Exit" />
</div>
